@@ -14,7 +14,7 @@ import pandas as pd
 from sklearn.utils import check_array
 from sklearn.utils.validation import check_is_fitted
 
-from featurebox.featurizers.base_transform import BaseFeature
+from featurebox.featurizers.base_feature import BaseFeature
 from featurebox.featurizers.state.extrastats import PropertyStats
 from featurebox.featurizers.state.statistics import DepartElementFeature
 
@@ -26,7 +26,7 @@ class UnionFeature(BaseFeature):
     Examples
     ---------
     >>> from featurebox.featurizers.atom.mapper import AtomTableMap, AtomJsonMap
-    >>> data_map = AtomJsonMap(search_tp="name", n_jobs=1)
+    >>> data_map = AtomJsonMap(search_tp="name_dict", n_jobs=1)
     >>> wa = DepartElementFeature(data_map,n_composition=2, n_jobs=1,return_type="df")
     >>> x3 = [{"H": 2, "Pd": 1},{"He":1,"Al":4}]
     >>> wa.set_feature_labels(["fea_{}".format(_) for _ in range(16)])
@@ -130,7 +130,8 @@ class PolyFeature(BaseFeature, ABC):
     >>> ps = pd.DataFrame(n,columns=["f1","f2"],index= ["x0","x1","x2","x3","x4","x5"])
     >>> pf = PolyFeature(degree=[1,2])
     >>> pf.fit_transform(n)
-       f0^1      f1^1  f0^2  f0^1*f1^1      f1^2
+
+    n   f0^1     f1^1  f0^2  f0^1*f1^1      f1^2
     0   0.0  0.422068   0.0   0.000000  0.178141
     1   1.0  0.360958   1.0   0.360958  0.130291
     2   2.0  0.201433   4.0   0.402866  0.040575
@@ -138,7 +139,6 @@ class PolyFeature(BaseFeature, ABC):
     4   4.0 -0.064783  16.0  -0.259132  0.004197
     5   5.0 -0.250939  25.0  -1.254695  0.062970
 
-
     """
 
     def __init__(self, *, degree: Union[int, List[int]] = 3, n_jobs=1, on_errors='raise', return_type='df'):
